# skypy
Python API Wrapper to connect to the Hypixel Skyblock API.

To get Started, head over to the [quickstart page](https://fuchscrafter.github.io/skypy/quickstart).

You can find the documentation in the [GitHub wiki](https://github.com/FuchsCrafter/skypy/wiki).

Find the work-in-progress example page [Here](https://fuchscrafter.github.io/skypy/examples/).

***
*skypy-api is maintained by [FuchsCrafter](https://github.com/FuchsCrafter)*